==> hadoop-client-api-3.3.4-sources.jar: org/apache/hadoop/yarn/server/api/protocolrecords/RefreshNodesResourcesRequest.java <==
/**
* Licensed to the Apache Software Foundation (ASF) under one
* or more contributor license agreements.  See the NOTICE file
* distributed with this work for additional information
* regarding copyright ownership.  The ASF licenses this file
* to you under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in org.apache.hadoop.shaded.com.liance
* with the License.  You may obtain a copy of the License at
*
*     http://www.apache.org.apache.hadoop.shaded.org.licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package org.apache.hadoop.shaded.org.apache.hadoop.yarn.server.api.protocolrecords;

import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceAudience.Private;
import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceAudience.Public;
import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceStability.Evolving;
import org.apache.hadoop.shaded.org.apache.hadoop.yarn.util.Records;

/**
 * Request to refresh the resources of a node.
 */
@Private
@Evolving
public abstract class RefreshNodesResourcesRequest {
  @Public
  @Evolving
  public static RefreshNodesResourcesRequest newInstance() {
    RefreshNodesResourcesRequest request =
        Records.newRecord(RefreshNodesResourcesRequest.class);
    return request;
  }
}

==> hadoop-client-api-3.4.0-sources.jar: org/apache/hadoop/yarn/server/api/protocolrecords/RefreshNodesResourcesRequest.java <==
/**
* Licensed to the Apache Software Foundation (ASF) under one
* or more contributor license agreements.  See the NOTICE file
* distributed with this work for additional information
* regarding copyright ownership.  The ASF licenses this file
* to you under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance
* with the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package org.apache.hadoop.shaded.org.apache.hadoop.yarn.server.api.protocolrecords;

import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceAudience.Private;
import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceAudience.Public;
import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceStability.Evolving;
import org.apache.hadoop.shaded.org.apache.hadoop.yarn.util.Records;

/**
 * Request to refresh the resources of a node.
 */
@Private
@Evolving
public abstract class RefreshNodesResourcesRequest {
  @Public
  @Evolving
  public static RefreshNodesResourcesRequest newInstance() {
    RefreshNodesResourcesRequest request =
        Records.newRecord(RefreshNodesResourcesRequest.class);
    return request;
  }

  @Public
  @Evolving
  public static RefreshNodesResourcesRequest newInstance(String subClusterId) {
    RefreshNodesResourcesRequest request =
        Records.newRecord(RefreshNodesResourcesRequest.class);
    request.setSubClusterId(subClusterId);
    return request;
  }

  /**
   * Get the subClusterId.
   *
   * @return subClusterId.
   */
  @Public
  @Evolving
  public abstract String getSubClusterId();

  /**
   * Set the subClusterId.
   *
   * @param subClusterId subCluster Id.
   */
  @Public
  @Evolving
  public abstract void setSubClusterId(String subClusterId);
}
